==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1ScaleIOVolumeSourceFluent.java <==
package io.kubernetes.client.models;

import java.lang.Deprecated;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Boolean;

public interface V1ScaleIOVolumeSourceFluent<A extends V1ScaleIOVolumeSourceFluent<A>> extends Fluent<A>{


    public String getFsType();
    public A withFsType(String fsType);
    public Boolean hasFsType();
    public String getGateway();
    public A withGateway(String gateway);
    public Boolean hasGateway();
    public String getProtectionDomain();
    public A withProtectionDomain(String protectionDomain);
    public Boolean hasProtectionDomain();
    public Boolean isReadOnly();
    public A withReadOnly(Boolean readOnly);
    public Boolean hasReadOnly();
    public A withNewReadOnly(boolean arg1);
    public A withNewReadOnly(String arg1);
    
/**
 * This method has been deprecated, please use method buildSecretRef instead.
 * @return The buildable object.
 */
@Deprecated public V1LocalObjectReference getSecretRef();
    public V1LocalObjectReference buildSecretRef();
    public A withSecretRef(V1LocalObjectReference secretRef);
    public Boolean hasSecretRef();
    public V1ScaleIOVolumeSourceFluent.SecretRefNested<A> withNewSecretRef();
    public V1ScaleIOVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(V1LocalObjectReference item);
    public V1ScaleIOVolumeSourceFluent.SecretRefNested<A> editSecretRef();
    public V1ScaleIOVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef();
    public V1ScaleIOVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(V1LocalObjectReference item);
    public Boolean isSslEnabled();
    public A withSslEnabled(Boolean sslEnabled);
    public Boolean hasSslEnabled();
    public A withNewSslEnabled(boolean arg1);
    public A withNewSslEnabled(String arg1);
    public String getStorageMode();
    public A withStorageMode(String storageMode);
    public Boolean hasStorageMode();
    public String getStoragePool();
    public A withStoragePool(String storagePool);
    public Boolean hasStoragePool();
    public String getSystem();
    public A withSystem(String system);
    public Boolean hasSystem();
    public String getVolumeName();
    public A withVolumeName(String volumeName);
    public Boolean hasVolumeName();

    public interface SecretRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1LocalObjectReferenceFluent<V1ScaleIOVolumeSourceFluent.SecretRefNested<N>>{

        
    public N and();    public N endSecretRef();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1ScaleIOVolumeSourceFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V1ScaleIOVolumeSourceFluent<A extends V1ScaleIOVolumeSourceFluent<A>> extends Fluent<A>{


    public String getFsType();
    public A withFsType(String fsType);
    public Boolean hasFsType();
    public A withNewFsType(String arg1);
    public A withNewFsType(StringBuilder arg1);
    public A withNewFsType(StringBuffer arg1);
    public String getGateway();
    public A withGateway(String gateway);
    public Boolean hasGateway();
    public A withNewGateway(String arg1);
    public A withNewGateway(StringBuilder arg1);
    public A withNewGateway(StringBuffer arg1);
    public String getProtectionDomain();
    public A withProtectionDomain(String protectionDomain);
    public Boolean hasProtectionDomain();
    public A withNewProtectionDomain(String arg1);
    public A withNewProtectionDomain(StringBuilder arg1);
    public A withNewProtectionDomain(StringBuffer arg1);
    public Boolean isReadOnly();
    public A withReadOnly(Boolean readOnly);
    public Boolean hasReadOnly();
    public A withNewReadOnly(String arg1);
    public A withNewReadOnly(boolean arg1);
    
/**
 * This method has been deprecated, please use method buildSecretRef instead.
 * @return The buildable object.
 */
@Deprecated public V1LocalObjectReference getSecretRef();
    public V1LocalObjectReference buildSecretRef();
    public A withSecretRef(V1LocalObjectReference secretRef);
    public Boolean hasSecretRef();
    public V1ScaleIOVolumeSourceFluent.SecretRefNested<A> withNewSecretRef();
    public V1ScaleIOVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(V1LocalObjectReference item);
    public V1ScaleIOVolumeSourceFluent.SecretRefNested<A> editSecretRef();
    public V1ScaleIOVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef();
    public V1ScaleIOVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(V1LocalObjectReference item);
    public Boolean isSslEnabled();
    public A withSslEnabled(Boolean sslEnabled);
    public Boolean hasSslEnabled();
    public A withNewSslEnabled(String arg1);
    public A withNewSslEnabled(boolean arg1);
    public String getStorageMode();
    public A withStorageMode(String storageMode);
    public Boolean hasStorageMode();
    public A withNewStorageMode(String arg1);
    public A withNewStorageMode(StringBuilder arg1);
    public A withNewStorageMode(StringBuffer arg1);
    public String getStoragePool();
    public A withStoragePool(String storagePool);
    public Boolean hasStoragePool();
    public A withNewStoragePool(String arg1);
    public A withNewStoragePool(StringBuilder arg1);
    public A withNewStoragePool(StringBuffer arg1);
    public String getSystem();
    public A withSystem(String system);
    public Boolean hasSystem();
    public A withNewSystem(String arg1);
    public A withNewSystem(StringBuilder arg1);
    public A withNewSystem(StringBuffer arg1);
    public String getVolumeName();
    public A withVolumeName(String volumeName);
    public Boolean hasVolumeName();
    public A withNewVolumeName(String arg1);
    public A withNewVolumeName(StringBuilder arg1);
    public A withNewVolumeName(StringBuffer arg1);

    public interface SecretRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1LocalObjectReferenceFluent<V1ScaleIOVolumeSourceFluent.SecretRefNested<N>>{

        
    public N and();    public N endSecretRef();
}


}
